Documentation
¶
Index ¶
- type AddLiffAppRequest
- type AddLiffAppResponse
- type GetAllLiffAppsResponse
- type LiffAPI
- func (client *LiffAPI) AddLIFFApp(addLiffAppRequest *AddLiffAppRequest) (*AddLiffAppResponse, error)
- func (client *LiffAPI) AddLIFFAppWithHttpInfo(addLiffAppRequest *AddLiffAppRequest) (*http.Response, *AddLiffAppResponse, error)
- func (client *LiffAPI) DeleteLIFFApp(liffId string) (struct{}, error)
- func (client *LiffAPI) DeleteLIFFAppWithHttpInfo(liffId string) (*http.Response, struct{}, error)
- func (client *LiffAPI) Do(req *http.Request) (*http.Response, error)
- func (client *LiffAPI) GetAllLIFFApps() (*GetAllLiffAppsResponse, error)
- func (client *LiffAPI) GetAllLIFFAppsWithHttpInfo() (*http.Response, *GetAllLiffAppsResponse, error)
- func (client *LiffAPI) UpdateLIFFApp(liffId string, updateLiffAppRequest *UpdateLiffAppRequest) (struct{}, error)
- func (client *LiffAPI) UpdateLIFFAppWithHttpInfo(liffId string, updateLiffAppRequest *UpdateLiffAppRequest) (*http.Response, struct{}, error)
- func (client *LiffAPI) Url(endpointPath string) string
- func (call *LiffAPI) WithContext(ctx context.Context) *LiffAPI
- type LiffAPIOption
- type LiffApp
- type LiffBotPrompt
- type LiffFeatures
- type LiffScope
- type LiffView
- type LiffViewTYPE
- type UpdateLiffAppRequest
- type UpdateLiffView
- type UpdateLiffViewTYPE
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddLiffAppRequest ¶
type AddLiffAppRequest struct {
/**
* Get View
*/
View *LiffView `json:"view"`
/**
* Name of the LIFF app. The LIFF app name can't include \"LINE\" or similar strings, or inappropriate strings.
*/
Description string `json:"description,omitempty"`
/**
* Get Features
*/
Features *LiffFeatures `json:"features,omitempty"`
/**
* How additional information in LIFF URLs is handled. Specify `concat`.
*/
PermanentLinkPattern string `json:"permanentLinkPattern,omitempty"`
/**
* Get Scope
*/
Scope []LiffScope `json:"scope,omitempty"`
/**
* Get BotPrompt
*/
BotPrompt LiffBotPrompt `json:"botPrompt,omitempty"`
}
AddLiffAppRequest AddLiffAppRequest https://developers.line.biz/en/reference/liff-server/#add-liff-app
type AddLiffAppResponse ¶
type AddLiffAppResponse struct {
/**
* Get LiffId
*/
LiffId string `json:"liffId"`
}
type GetAllLiffAppsResponse ¶
type GetAllLiffAppsResponse struct {
/**
* Get Apps
*/
Apps []LiffApp `json:"apps,omitempty"`
}
type LiffAPI ¶
type LiffAPI struct {
// contains filtered or unexported fields
}
func NewLiffAPI ¶
func NewLiffAPI(channelToken string, options ...LiffAPIOption) (*LiffAPI, error)
New returns a new bot client instance.
func (*LiffAPI) AddLIFFApp ¶
func (client *LiffAPI) AddLIFFApp( addLiffAppRequest *AddLiffAppRequest, ) (*AddLiffAppResponse, error)
https://developers.line.biz/en/reference/liff-server/#add-liff-app
func (*LiffAPI) AddLIFFAppWithHttpInfo ¶
func (client *LiffAPI) AddLIFFAppWithHttpInfo( addLiffAppRequest *AddLiffAppRequest, ) (*http.Response, *AddLiffAppResponse, error)
https://developers.line.biz/en/reference/liff-server/#add-liff-app
func (*LiffAPI) DeleteLIFFApp ¶
https://developers.line.biz/en/reference/liff-server/#delete-liff-app
func (*LiffAPI) DeleteLIFFAppWithHttpInfo ¶
func (client *LiffAPI) DeleteLIFFAppWithHttpInfo( liffId string, ) (*http.Response, struct{}, error)
https://developers.line.biz/en/reference/liff-server/#delete-liff-app
func (*LiffAPI) GetAllLIFFApps ¶
func (client *LiffAPI) GetAllLIFFApps() (*GetAllLiffAppsResponse, error)
https://developers.line.biz/en/reference/liff-server/#get-all-liff-apps
func (*LiffAPI) GetAllLIFFAppsWithHttpInfo ¶
func (client *LiffAPI) GetAllLIFFAppsWithHttpInfo() (*http.Response, *GetAllLiffAppsResponse, error)
https://developers.line.biz/en/reference/liff-server/#get-all-liff-apps
func (*LiffAPI) UpdateLIFFApp ¶
func (client *LiffAPI) UpdateLIFFApp( liffId string, updateLiffAppRequest *UpdateLiffAppRequest, ) (struct{}, error)
https://developers.line.biz/en/reference/liff-server/#update-liff-app
func (*LiffAPI) UpdateLIFFAppWithHttpInfo ¶
func (client *LiffAPI) UpdateLIFFAppWithHttpInfo( liffId string, updateLiffAppRequest *UpdateLiffAppRequest, ) (*http.Response, struct{}, error)
https://developers.line.biz/en/reference/liff-server/#update-liff-app
type LiffAPIOption ¶
LiffAPIOption type
type LiffApp ¶
type LiffApp struct {
/**
* LIFF app ID
*/
LiffId string `json:"liffId,omitempty"`
/**
* Get View
*/
View *LiffView `json:"view,omitempty"`
/**
* Name of the LIFF app
*/
Description string `json:"description,omitempty"`
/**
* Get Features
*/
Features *LiffFeatures `json:"features,omitempty"`
/**
* How additional information in LIFF URLs is handled. concat is returned.
*/
PermanentLinkPattern string `json:"permanentLinkPattern,omitempty"`
/**
* Get Scope
*/
Scope []LiffScope `json:"scope,omitempty"`
/**
* Get BotPrompt
*/
BotPrompt LiffBotPrompt `json:"botPrompt,omitempty"`
}
type LiffBotPrompt ¶
type LiffBotPrompt string
LiffBotPrompt type
const ( LiffBotPrompt_NORMAL LiffBotPrompt = "normal" LiffBotPrompt_AGGRESSIVE LiffBotPrompt = "aggressive" LiffBotPrompt_NONE LiffBotPrompt = "none" )
LiffBotPrompt constants
type LiffFeatures ¶
type LiffView ¶
type LiffView struct {
/**
* Size of the LIFF app view. Specify one of these values: - compact - tall - full (Required)
*/
Type LiffViewTYPE `json:"type"`
/**
* Endpoint URL. This is the URL of the web app that implements the LIFF app (e.g. https://example.com). Used when the LIFF app is launched using the LIFF URL. The URL scheme must be https. URL fragments (#URL-fragment) can't be specified. (Required)
*/
Url string `json:"url"`
/**
* `true` to use the LIFF app in modular mode. When in modular mode, the action button in the header is not displayed.
*/
ModuleMode bool `json:"moduleMode"`
}
LiffView LiffView https://developers.line.biz/en/reference/liff-server/#add-liff-app
type LiffViewTYPE ¶
type LiffViewTYPE string
LiffViewTYPE type
Size of the LIFF app view. Specify one of these values: - compact - tall - full
const ( LiffViewTYPE_COMPACT LiffViewTYPE = "compact" LiffViewTYPE_TALL LiffViewTYPE = "tall" LiffViewTYPE_FULL LiffViewTYPE = "full" )
LiffViewTYPE constants
type UpdateLiffAppRequest ¶
type UpdateLiffAppRequest struct {
/**
* Get View
*/
View *UpdateLiffView `json:"view,omitempty"`
/**
* Name of the LIFF app. The LIFF app name can't include \"LINE\" or similar strings, or inappropriate strings.
*/
Description string `json:"description,omitempty"`
/**
* Get Features
*/
Features *LiffFeatures `json:"features,omitempty"`
/**
* How additional information in LIFF URLs is handled. Specify `concat`.
*/
PermanentLinkPattern string `json:"permanentLinkPattern,omitempty"`
/**
* Get Scope
*/
Scope []LiffScope `json:"scope,omitempty"`
/**
* Get BotPrompt
*/
BotPrompt LiffBotPrompt `json:"botPrompt,omitempty"`
}
UpdateLiffAppRequest UpdateLiffAppRequest https://developers.line.biz/en/reference/liff-server/#add-liff-app
type UpdateLiffView ¶ added in v8.9.1
type UpdateLiffView struct {
/**
* Size of the LIFF app view. Specify one of these values: - compact - tall - full
*/
Type UpdateLiffViewTYPE `json:"type,omitempty"`
/**
* Endpoint URL. This is the URL of the web app that implements the LIFF app (e.g. https://example.com). Used when the LIFF app is launched using the LIFF URL. The URL scheme must be https. URL fragments (#URL-fragment) can't be specified.
*/
Url string `json:"url,omitempty"`
/**
* `true` to use the LIFF app in modular mode. When in modular mode, the action button in the header is not displayed.
*/
ModuleMode bool `json:"moduleMode"`
}
UpdateLiffView UpdateLiffView https://developers.line.biz/en/reference/liff-server/#update-liff-app
type UpdateLiffViewTYPE ¶ added in v8.9.1
type UpdateLiffViewTYPE string
UpdateLiffViewTYPE type
Size of the LIFF app view. Specify one of these values: - compact - tall - full
const ( UpdateLiffViewTYPE_COMPACT UpdateLiffViewTYPE = "compact" UpdateLiffViewTYPE_TALL UpdateLiffViewTYPE = "tall" UpdateLiffViewTYPE_FULL UpdateLiffViewTYPE = "full" )
UpdateLiffViewTYPE constants